==> haskell-primitive-0.7.3.0-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 primitive
version:              0.7.3.0
visibility:           public
id:                   primitive-0.7.3.0-HsqtLhuAIqYHZIsIWpkf26
key:                  primitive-0.7.3.0-HsqtLhuAIqYHZIsIWpkf26
license:              BSD-3-Clause
copyright:            (c) Roman Leshchinskiy 2009-2012
maintainer:           libraries@haskell.org
author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/primitive
synopsis:             Primitive memory-related operations
description:
    This package provides various primitive memory-related operations.

category:             Data
abi:                  79ce9f76b162df064949ee78c9f75322
exposed:              True
exposed-modules:
    Control.Monad.Primitive Data.Primitive Data.Primitive.Array
    Data.Primitive.ByteArray Data.Primitive.MVar
    Data.Primitive.MachDeps Data.Primitive.MutVar
    Data.Primitive.PrimArray Data.Primitive.Ptr
    Data.Primitive.SmallArray Data.Primitive.Types

hidden-modules:       Data.Primitive.Internal.Operations
import-dirs:          /usr/lib/ghc-9.0.2/site-local/primitive-0.7.3.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/primitive-0.7.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/primitive-0.7.3.0
hs-libraries:         HSprimitive-0.7.3.0-HsqtLhuAIqYHZIsIWpkf26
include-dirs:         /usr/lib/ghc-9.0.2/site-local/primitive-0.7.3.0/include
includes:             primitive-memops.h
depends:              base-4.15.1.0 deepseq-1.4.5.0 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-primitive/html/primitive.haddock
haddock-html:         /usr/share/doc/haskell-primitive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primitive-0.7.3.0-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 primitive
version:              0.7.3.0
visibility:           public
id:                   primitive-0.7.3.0-6mJnOlsjOaQ2INtjd9hIci
key:                  primitive-0.7.3.0-6mJnOlsjOaQ2INtjd9hIci
license:              BSD-3-Clause
copyright:            (c) Roman Leshchinskiy 2009-2012
maintainer:           libraries@haskell.org
author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/primitive
synopsis:             Primitive memory-related operations
description:
    This package provides various primitive memory-related operations.

category:             Data
abi:                  2d49d8bc27de4141d211958146e7ba3e
exposed:              True
exposed-modules:
    Control.Monad.Primitive Data.Primitive Data.Primitive.Array
    Data.Primitive.ByteArray Data.Primitive.MVar
    Data.Primitive.MachDeps Data.Primitive.MutVar
    Data.Primitive.PrimArray Data.Primitive.Ptr
    Data.Primitive.SmallArray Data.Primitive.Types

hidden-modules:       Data.Primitive.Internal.Operations
import-dirs:          /usr/lib/ghc-9.0.2/site-local/primitive-0.7.3.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/primitive-0.7.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/primitive-0.7.3.0
hs-libraries:         HSprimitive-0.7.3.0-6mJnOlsjOaQ2INtjd9hIci
include-dirs:         /usr/lib/ghc-9.0.2/site-local/primitive-0.7.3.0/include
includes:             primitive-memops.h
depends:              base-4.15.1.0 deepseq-1.4.5.0 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-primitive/html/primitive.haddock
haddock-html:         /usr/share/doc/haskell-primitive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
